measuretools.set_measure_denominator_and_adjust_numerator
=========================================================

.. autofunction:: abjad.tools.measuretools.set_measure_denominator_and_adjust_numerator.set_measure_denominator_and_adjust_numerator
